@@ -13,9 +13,13 @@ use vars qw(
 	$Quiet
 	);
 
-$VERSION = '1.003';
+$VERSION = '1.004';
 
-@EXPORT_OK = qw( prompt find_files copy gitify content );
+@EXPORT_OK = qw(
+	prompt find_files copy gitify content
+	script_template
+	%Content
+	);
 %EXPORT_TAGS = (
 	'all' => [ @EXPORT_OK ],
 	);
